# KangRollGeneCancer/__init__.py
# from .core import multi_layer_network
# # 可以继续导入其他需要的模块


# KangRollGeneCancer/__init__.py

# 导入核心模块
from .core import update_network, IS_KANGROLL_PRODUCTION, KANGROLL_PRODUCTION_KEY # ,test_function

# 导入模型模块
# from .models import analyze_gene

# 导入实用工具模块
# from .utils import some_utility_function

# 此处可以添加更多的导入语句，以方便包的使用者访问各个子模块


# 理解了。实际上就是增加了调取的灵活性。 从一层包装下调取。可以，从两层包装下调取也可，总之，总能调取到。方便我调取。哪怕不知道他父亲或爷爷的名字？
